@@ -7,7 +7,8 @@ import warnings
 
 import eventlet
 from eventlet.hubs import trampoline, notify_opened, IOClosed
-from eventlet.support import get_errno, six
+from eventlet.support import get_errno
+import six
 
 __all__ = [
     'GreenSocket', '_GLOBAL_DEFAULT_TIMEOUT', 'set_nonblocking',
@@ -212,13 +213,16 @@ class GreenSocket(object):
 
     def accept(self):
         if self.act_non_blocking:
-            return self.fd.accept()
+            res = self.fd.accept()
+            notify_opened(res[0].fileno())
+            return res
         fd = self.fd
         _timeout_exc = socket_timeout('timed out')
         while True:
             res = socket_accept(fd)
             if res is not None:
                 client, addr = res
+                notify_opened(client.fileno())
                 set_nonblocking(client)
                 return type(self)(client), addr
             self._trampoline(fd, read=True, timeout=self.gettimeout(), timeout_exc=_timeout_exc)
@@ -428,6 +432,12 @@ class GreenSocket(object):
     def gettimeout(self):
         return self._timeout
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.close()
+
     if "__pypy__" in sys.builtin_module_names:
         def _reuse(self):
             getattr(self.fd, '_sock', self.fd)._reuse()
@@ -472,11 +482,11 @@ except ImportError:
 
 
 def shutdown_safe(sock):
-    """ Shuts down the socket. This is a convenience method for
+    """Shuts down the socket. This is a convenience method for
     code that wants to gracefully handle regular sockets, SSL.Connection
-    sockets from PyOpenSSL and ssl.SSLSocket objects from Python 2.6
-    interchangeably.  Both types of ssl socket require a shutdown() before
-    close, but they have different arity on their shutdown method.
+    sockets from PyOpenSSL and ssl.SSLSocket objects from Python 2.7 interchangeably.
+    Both types of ssl socket require a shutdown() before close,
+    but they have different arity on their shutdown method.
 
     Regular sockets don't need a shutdown before close, but it doesn't hurt.
     """
